@@ -53,7 +53,7 @@ def test_serialize_node__prompt_inputs__constant_value():
     )
 
     assert prompt_inputs_attribute == {
-        "id": "3d9a4d2e-c9bd-4417-8a0c-52f15efdbe30",
+        "id": "fb85d86d-f291-4a0d-b867-f7545df7af59",
         "name": "prompt_inputs",
         "value": {"type": "CONSTANT_VALUE", "value": {"type": "JSON", "value": {"foo": "bar"}}},
     }
@@ -86,13 +86,13 @@ def test_serialize_node__prompt_inputs__input_reference():
     )
 
     assert prompt_inputs_attribute == {
-        "id": "6cde4776-7f4a-411c-95a8-69c8b3a64b42",
+        "id": "80ed13f9-64d2-47ee-bb91-3378de7ad2c0",
         "name": "prompt_inputs",
         "value": {
             "type": "DICTIONARY_REFERENCE",
             "entries": [
                 {
-                    "id": "845009c8-03f8-4de4-b956-841309457d37",
+                    "id": "981b8cdf-c08d-42a1-a226-76de8acf192f",
                     "key": "foo",
                     "value": {"type": "WORKFLOW_INPUT", "input_variable_id": "e3657390-fd3c-4fea-8cdd-fc5ea79f3278"},
                 }
@@ -128,18 +128,18 @@ def test_serialize_node__prompt_inputs__mixed_values():
     )
 
     assert prompt_inputs_attribute == {
-        "id": "c4ca6e3d-0f71-4802-a618-1e87880cb7cf",
+        "id": "7352d310-204c-4291-8757-a84a6e68591a",
         "name": "prompt_inputs",
         "value": {
             "type": "DICTIONARY_REFERENCE",
             "entries": [
                 {
-                    "id": "a4016385-3cab-4c01-b9d2-7865cd54bdb0",
+                    "id": "05c092c7-4031-43b7-8c3d-b1a317ca271d",
                     "key": "foo",
                     "value": {"type": "CONSTANT_VALUE", "value": {"type": "STRING", "value": "bar"}},
                 },
                 {
-                    "id": "828928b1-24e3-4457-9d6f-4f0692dfa355",
+                    "id": "b0de6603-fcdd-44a3-b33a-56f05bd03bb4",
                     "key": "baz",
                     "value": {"type": "WORKFLOW_INPUT", "input_variable_id": "8d57cf1d-147c-427b-9a5e-e5f6ab76e2eb"},
                 },
@@ -181,7 +181,7 @@ def test_serialize_node__tool_calling_node__mcp_server_api_key():
     )
 
     assert functions_attribute == {
-        "id": "6c0f7d4f-3c8a-4201-b588-8398d3c97480",
+        "id": "ff00c2d6-f99c-458b-9bcd-181f8e43b2d1",
         "name": "functions",
         "value": {
             "type": "CONSTANT_VALUE",
@@ -234,7 +234,7 @@ def test_serialize_node__tool_calling_node__mcp_server_no_authorization():
     )
 
     assert functions_attribute == {
-        "id": "c8957551-cb3d-49af-8053-acd256c1d852",
+        "id": "a8a0133f-7913-451a-89da-f8dea5f352a2",
         "name": "functions",
         "value": {
             "type": "CONSTANT_VALUE",
@@ -297,11 +297,11 @@ def test_serialize_tool_router_node():
         "adornments": None,
         "attributes": [
             {
-                "id": "cd208919-c66b-451b-a739-bcf7d3451dea",
+                "id": "ea36d8ff-3f6e-41eb-8a7b-ba3ca8e05f49",
                 "name": "prompt_outputs",
                 "value": {
-                    "node_id": "19e664fc-3b57-48d2-b47a-b143b475406a",
-                    "node_output_id": "c2a5a7f7-a234-45dc-adee-bc6fc0bd28dd",
+                    "node_id": "c75146e1-ea10-4f58-90fd-887322725496",
+                    "node_output_id": "baef5c93-612a-453d-b739-223041ef0429",
                     "type": "NODE_OUTPUT",
                 },
             }
@@ -315,7 +315,7 @@ def test_serialize_tool_router_node():
             "name": "RouterNode",
         },
         "display_data": {"position": {"x": 0.0, "y": 0.0}},
-        "id": "690c66e1-1e18-4984-b695-84beb0157541",
+        "id": "d2884fa0-2d3d-4220-a335-bdcef56a00d5",
         "label": "Router Node",
         "outputs": [],
         "ports": [
@@ -330,8 +330,8 @@ def test_serialize_tool_router_node():
                             "operator": "<",
                             "rhs": {
                                 "lhs": {
-                                    "node_id": "19e664fc-3b57-48d2-b47a-b143b475406a",
-                                    "node_output_id": "c2a5a7f7-a234-45dc-adee-bc6fc0bd28dd",
+                                    "node_id": "c75146e1-ea10-4f58-90fd-887322725496",
+                                    "node_output_id": "baef5c93-612a-453d-b739-223041ef0429",
                                     "type": "NODE_OUTPUT",
                                 },
                                 "operator": "length",
@@ -344,8 +344,8 @@ def test_serialize_tool_router_node():
                             "lhs": {
                                 "lhs": {
                                     "lhs": {
-                                        "node_id": "19e664fc-3b57-48d2-b47a-b143b475406a",
-                                        "node_output_id": "c2a5a7f7-a234-45dc-adee-bc6fc0bd28dd",
+                                        "node_id": "c75146e1-ea10-4f58-90fd-887322725496",
+                                        "node_output_id": "baef5c93-612a-453d-b739-223041ef0429",
                                         "type": "NODE_OUTPUT",
                                     },
                                     "operator": "accessField",
@@ -371,8 +371,8 @@ def test_serialize_tool_router_node():
                             "lhs": {
                                 "lhs": {
                                     "lhs": {
-                                        "node_id": "19e664fc-3b57-48d2-b47a-b143b475406a",
-                                        "node_output_id": "c2a5a7f7-a234-45dc-adee-bc6fc0bd28dd",
+                                        "node_id": "c75146e1-ea10-4f58-90fd-887322725496",
+                                        "node_output_id": "baef5c93-612a-453d-b739-223041ef0429",
                                         "type": "NODE_OUTPUT",
                                     },
                                     "operator": "accessField",
@@ -396,13 +396,13 @@ def test_serialize_tool_router_node():
                     },
                     "type": "BINARY_EXPRESSION",
                 },
-                "id": "afb4b09d-659b-459e-9a28-cf73ba6e0574",
+                "id": "81d85d92-7f51-4f41-84be-8e2b0eeb4f59",
                 "name": "my_function",
                 "type": "IF",
             },
-            {"expression": None, "id": "4ecd916e-b5d0-407e-aab4-35551c76d02c", "name": "default", "type": "ELSE"},
+            {"expression": None, "id": "a433bba4-a0d6-44f3-b53b-0d5231e442cf", "name": "default", "type": "ELSE"},
         ],
-        "trigger": {"id": "73a96f44-c2dd-40cc-96f6-49b9f914b166", "merge_behavior": "AWAIT_ATTRIBUTES"},
+        "trigger": {"id": "9055a5d0-68a1-40cf-bc05-a8c65bd19abe", "merge_behavior": "AWAIT_ATTRIBUTES"},
         "type": "GENERIC",
     }
 
@@ -469,7 +469,7 @@ def test_serialize_node__tool_calling_node__subworkflow_with_parent_input_refere
     assert code_exec_node is not None
     text_input = next((input for input in code_exec_node["inputs"] if input["key"] == "text"), None)
     assert text_input == {
-        "id": "da92a1c4-d37c-4008-a1ab-c0bcc0cd20d0",
+        "id": "9f3a85b5-a0c7-4b72-beef-d68b4eb2a428",
         "key": "text",
         "value": {
             "rules": [
@@ -534,13 +534,13 @@ def test_serialize_tool_prompt_node_with_inline_workflow():
         (attr for attr in attributes if isinstance(attr, dict) and attr["name"] == "prompt_inputs"), None
     )
     assert prompt_inputs_attr == {
-        "id": "bc1320a2-23e4-4238-8b00-efbf88e91856",
+        "id": "d218d7c7-41f4-46d4-a9ed-89640cba1b9b",
         "name": "prompt_inputs",
         "value": {
             "type": "DICTIONARY_REFERENCE",
             "entries": [
                 {
-                    "id": "b1dfaf2b-b9fb-4fea-ad04-a988e5223d06",
+                    "id": "c181c554-a97f-4254-9bc8-1c30a8f3fb5f",
                     "key": "chat_history",
                     "value": {
                         "type": "BINARY_EXPRESSION",
@@ -628,7 +628,7 @@ def test_serialize_tool_prompt_node_with_workflow_deployment(vellum_client):
     assert isinstance(attributes, list)
     functions_attr = next((attr for attr in attributes if isinstance(attr, dict) and attr["name"] == "functions"), None)
     assert functions_attr == {
-        "id": "6326ccc4-7cf6-4235-ba3c-a6e860b0c48b",
+        "id": "f482dc81-e320-402d-83df-f60d278797d8",
         "name": "functions",
         "value": {
             "type": "CONSTANT_VALUE",
