@@ -6,11 +6,13 @@ import inspect
 import json
 import logging
 import os
+import traceback
 from uuid import UUID
 from typing import Any, Dict, ForwardRef, Generic, List, Optional, Set, Tuple, Type, TypeVar, Union, cast, get_args
 
 from vellum.client import Vellum as VellumClient
 from vellum.client.core.pydantic_utilities import UniversalBaseModel
+from vellum.utils.json_encoder import VellumJsonEncoder
 from vellum.workflows import BaseWorkflow
 from vellum.workflows.constants import undefined
 from vellum.workflows.descriptors.base import BaseDescriptor
@@ -25,7 +27,6 @@ from vellum.workflows.nodes.displayable.final_output_node.node import FinalOutpu
 from vellum.workflows.nodes.utils import get_unadorned_node, get_unadorned_port, get_wrapped_node
 from vellum.workflows.ports import Port
 from vellum.workflows.references import OutputReference, WorkflowInputReference
-from vellum.workflows.state.encoder import DefaultStateEncoder
 from vellum.workflows.triggers.integration import IntegrationTrigger
 from vellum.workflows.triggers.manual import ManualTrigger
 from vellum.workflows.triggers.schedule import ScheduleTrigger
@@ -80,9 +81,14 @@ IGNORE_PATTERNS = [
 ]
 
 
+class WorkflowSerializationError(UniversalBaseModel):
+    message: str
+    stacktrace: str
+
+
 class WorkflowSerializationResult(UniversalBaseModel):
     exec_config: Dict[str, Any]
-    errors: List[str]
+    errors: List[WorkflowSerializationError]
     dataset: Optional[List[Dict[str, Any]]] = None
 
 
@@ -569,28 +575,63 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
             trigger_id = trigger_class.__id__
 
             # Serialize trigger attributes like node outputs
-            attribute_references = trigger_class.attribute_references().values()
-            trigger_attributes: JsonArray = cast(
-                JsonArray,
-                [
-                    cast(
-                        JsonObject,
-                        {
-                            "id": str(reference.id),
-                            "name": reference.name,
-                            "type": primitive_type_to_vellum_variable_type(reference),
-                            "value": None,
-                        },
-                    )
-                    for reference in sorted(attribute_references, key=lambda ref: ref.name)
-                ],
-            )
+            trigger_data: JsonObject
+            if trigger_type == WorkflowTriggerType.SCHEDULED:
+                # For scheduled triggers, attributes should be empty
+                # and cron/timezone should be top level
 
-            trigger_data: JsonObject = {
-                "id": str(trigger_id),
-                "type": trigger_type.value,
-                "attributes": trigger_attributes,
-            }
+                config_class = trigger_class.Config
+                cron_value = getattr(config_class, "cron", None)
+                timezone_value = getattr(config_class, "timezone", None)
+
+                trigger_data = {
+                    "id": str(trigger_id),
+                    "type": trigger_type.value,
+                    "cron": cron_value,
+                    "timezone": timezone_value,
+                    "attributes": [],
+                }
+            else:
+                # For other triggers, serialize attributes from attribute_references as VellumVariables
+                attribute_references = trigger_class.attribute_references().values()
+                trigger_attributes: JsonArray = cast(
+                    JsonArray,
+                    [
+                        cast(
+                            JsonObject,
+                            {
+                                "id": str(reference.id),
+                                "key": reference.name,
+                                "type": primitive_type_to_vellum_variable_type(reference),
+                                "required": True,
+                                "default": None,
+                                "extensions": None,
+                            },
+                        )
+                        for reference in sorted(attribute_references, key=lambda ref: ref.name)
+                    ],
+                )
+
+                trigger_data = {
+                    "id": str(trigger_id),
+                    "type": trigger_type.value,
+                    "attributes": trigger_attributes,
+                }
+
+            # Serialize display_data from trigger's Display class
+            display_class = trigger_class.Display
+            display_data: JsonObject = {}
+
+            # Add icon if present
+            if hasattr(display_class, "icon") and display_class.icon is not None:
+                display_data["icon"] = display_class.icon
+
+            # Add color if present
+            if hasattr(display_class, "color") and display_class.color is not None:
+                display_data["color"] = display_class.color
+
+            if display_data:
+                trigger_data["display_data"] = display_data
 
             # For INTEGRATION and SCHEDULED triggers, include class name, module path, and source_handle_id
             # ManualTrigger doesn't need source_handle_id because edges come from ENTRYPOINT node
@@ -1108,17 +1149,23 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
                     dataset = []
                     for i, inputs_obj in enumerate(dataset_attr):
                         if isinstance(inputs_obj, DatasetRow):
-                            serialized_inputs = json.loads(json.dumps(inputs_obj.inputs, cls=DefaultStateEncoder))
+                            serialized_inputs = json.loads(json.dumps(inputs_obj.inputs, cls=VellumJsonEncoder))
                             dataset.append({"label": inputs_obj.label, "inputs": serialized_inputs})
                         elif isinstance(inputs_obj, BaseInputs):
-                            serialized_inputs = json.loads(json.dumps(inputs_obj, cls=DefaultStateEncoder))
+                            serialized_inputs = json.loads(json.dumps(inputs_obj, cls=VellumJsonEncoder))
                             dataset.append({"label": f"Scenario {i + 1}", "inputs": serialized_inputs})
         except (ImportError, AttributeError):
             pass
 
         return WorkflowSerializationResult(
             exec_config=exec_config,
-            errors=[str(error) for error in workflow_display.display_context.errors],
+            errors=[
+                WorkflowSerializationError(
+                    message=str(error),
+                    stacktrace="".join(traceback.format_exception(type(error), error, error.__traceback__)),
+                )
+                for error in workflow_display.display_context.errors
+            ],
             dataset=dataset,
         )
 
