@@ -7,7 +7,7 @@ from pydantic import Field, GetCoreSchemaHandler, Tag, ValidationInfo
 from pydantic_core import CoreSchema, core_schema
 
 from vellum.client.core.pydantic_utilities import UniversalBaseModel
-from vellum.workflows.state.encoder import DefaultStateEncoder
+from vellum.utils.json_encoder import VellumJsonEncoder
 from vellum.workflows.types.definition import VellumCodeResourceDefinition
 from vellum.workflows.types.utils import datetime_now
 
@@ -24,7 +24,7 @@ def default_serializer(obj: Any) -> Any:
     return json.loads(
         json.dumps(
             obj,
-            cls=DefaultStateEncoder,
+            cls=VellumJsonEncoder,
         )
     )
 
@@ -74,6 +74,9 @@ class WorkflowSandboxParentContext(BaseParentContext):
 
 class APIRequestParentContext(BaseParentContext):
     type: Literal["API_REQUEST"] = "API_REQUEST"
+    api_actor_id: Optional[str] = None
+    api_actor_type: Optional[str] = None
+    api_actor_label: Optional[str] = None
 
 
 class UnknownParentContext(BaseParentContext):
